@@ -177,6 +177,7 @@ void initcfg()
   outgoing_utf8 = 1;
   log_charconv = 0;
   log_single_lines = 1;
+  executable_check = 1;
 
   message_count = 0;
 
@@ -201,6 +202,7 @@ void initcfg()
     devices[i].name[0]=0;
     devices[i].device[0]=0;
     devices[i].identity[0] = 0;
+    devices[i].conf_identity[0] = 0;
     //devices[i].identity_header[0] = 0;
     devices[i].incoming=0;
     devices[i].outgoing=1;
@@ -247,6 +249,8 @@ void initcfg()
     devices[i].dev_rr_statfile[0] = 0;
     devices[i].logfile[0] = 0;
     devices[i].loglevel = -1;
+    devices[i].messageids = 2;
+    devices[i].voicecall_vts_list = 0;
   }
   startup_err_str = NULL;
   startup_err_count = 0;
@@ -542,6 +546,12 @@ int readcfg()
           startuperror(yesno_error, name, value);
       }
       else
+      if (strcasecmp(name,"executable_check")==0)
+      {
+        if ((executable_check = yesno_check(ask_value(0, name, value))) == -1)
+          startuperror(yesno_error, name, value);
+      }
+      else
       if (strcasecmp(name,"user")==0)
         strcpy2(username, ask_value(0, name, value));
       else
@@ -924,13 +934,25 @@ int readcfg()
                 strcpy2(devices[device].dev_rr_statfile, ask_value(device_name, name, value));
 	      else
               if (strcasecmp(name,"logfile")==0)
-                strcpy2(devices[device].logfile, ask_value(0, name, value));
+                strcpy2(devices[device].logfile, ask_value(device_name, name, value));
               else
               if (strcasecmp(name,"loglevel")==0)
-                devices[device].loglevel = set_level(devices[device].name, name, strcpy(value, ask_value(0, name, value)));
+                devices[device].loglevel = set_level(devices[device].name, name, strcpy(value, ask_value(device_name, name, value)));
               else
               if (strcasecmp(name,"check_network")==0)
-                devices[device].check_network = atoi(ask_value(0, name, value));
+                devices[device].check_network = atoi(ask_value(device_name, name, value));
+              else
+              if (strcasecmp(name,"messageids")==0)
+                devices[device].messageids = atoi(ask_value(device_name, name, value));
+              else
+              if (strcasecmp(name,"voicecall_vts_list")==0)
+              {
+    	        if ((devices[device].voicecall_vts_list = yesno_check(ask_value(device_name, name, value))) == -1)
+                  startuperror(yesno_error, name, value);
+              }
+              else
+              if (strcasecmp(name,"identity")==0)
+                strcpy2(devices[device].conf_identity, ask_value(device_name, name, value));
               else
 	        startuperror("Unknown variable in config file for modem %s: %s\n", device_name, name);
 
@@ -949,6 +971,7 @@ int readcfg()
           break;
       }
     }
+
     fclose(File);
     set_alarmhandler(alarmhandler,alarmlevel);
     // if loglevel is unset, then set it depending on if we use syslog or a logfile
@@ -1097,6 +1120,19 @@ void parsearguments(int argc,char** argv)
   arg_terminal = 0;
   communicate[0] = 0;
 
+  // 3.1.1: Start and stop options are provided by the script, not by the daemon:
+  int i;
+
+  for (i = 1; i < argc; i++)
+  {
+    if (!strcasecmp(argv[i], "START") || !strcasecmp(argv[i], "STOP"))
+    {
+      printf("Invalid option for smsd: %s. Use the sms3 script (or equivalent) for start and stop operations.\n", argv[i]);
+      exit(0);
+    }
+  }
+  // --------
+
   do
   {
     result=getopt(argc,argv,"asthc:Vi:p:l:u:g:C:");
@@ -1323,7 +1359,7 @@ int startup_check(int result)
     x++;
   }
 
-  if (*eventhandler)
+  if (*eventhandler && executable_check)
   {
     if (!(fp = fopen(eventhandler, "r")))
       wrlogfile(&result, "Eventhandler %s cannot be read: %s", eventhandler, strerror(errno));
@@ -1335,7 +1371,7 @@ int startup_check(int result)
     }
   }
 
-  if (*checkhandler)
+  if (*checkhandler && executable_check)
   {
     if (!(fp = fopen(checkhandler, "r")))
       wrlogfile(&result, "Checkhandler %s cannot be read: %s", checkhandler, strerror(errno));
@@ -1347,7 +1383,7 @@ int startup_check(int result)
     }
   }
 
-  if (*alarmhandler)
+  if (*alarmhandler && executable_check)
   {
     if (!(fp = fopen(alarmhandler, "r")))
       wrlogfile(&result, "Alarmhandler %s cannot be read: %s", alarmhandler, strerror(errno));
@@ -1359,7 +1395,7 @@ int startup_check(int result)
     }
   }
 
-  if (*regular_run)
+  if (*regular_run && executable_check)
   {
     if (!(fp = fopen(regular_run, "r")))
       wrlogfile(&result, "Regular run %s cannot be read: %s", regular_run, strerror(errno));
@@ -1382,7 +1418,7 @@ int startup_check(int result)
         if (devices[x].queues[0][0] == 0)
           wrlogfile(&result, "Queues are used, but %s has no queue(s) defined.", devices[x].name);
 
-      if (devices[x].eventhandler[0] && strcmp(eventhandler, devices[x].eventhandler) != 0)
+      if (devices[x].eventhandler[0] && strcmp(eventhandler, devices[x].eventhandler) != 0 && executable_check)
       {
         if (!(fp = fopen(devices[x].eventhandler, "r")))
           wrlogfile(&result, "%s eventhandler %s cannot be read: %s", devices[x].name, devices[x].eventhandler, strerror(errno));
@@ -1405,7 +1441,7 @@ int startup_check(int result)
         }
       }
 
-      if (devices[x].dev_rr[0])
+      if (devices[x].dev_rr[0] && executable_check)
       {
         if (!(fp = fopen(devices[x].dev_rr, "r")))
           wrlogfile(&result, "%s regular_run file %s cannot be read: %s", devices[x].name, devices[x].dev_rr, strerror(errno));
@@ -1453,6 +1489,10 @@ int startup_check(int result)
               wrlogfile(&result, "Devices %s and %s has the same regular_run_statfile %s.", devices[x].name, devices[y].name, devices[x].dev_rr_statfile);
         }
       }
+
+      if (devices[x].messageids < 1 || devices[x].messageids > 3)
+        wrlogfile(&result, "Device %s has invalid value for messageids (%i).", devices[x].name, devices[x].messageids);
+
     }
   }
 
